@@ -3,7 +3,8 @@ from django.db.models import QuerySet, Q
 
 from djangoldp.utils import is_authenticated_user
 from djangoldp.permissions import LDPPermissions, LDPObjectLevelPermissions
-from djangoldp_circle.filters import CircleFilterBackend, CircleMemberFilterBackend
+from djangoldp_circle.filters import CircleFilterBackend, CircleMemberFilterBackend, \
+    CircleAccessRequestFilterBackend
 from djangoldp_circle.xmpp import get_client_ip, XMPP_SERVERS
 
 
@@ -103,3 +104,21 @@ class CircleMemberPermissions(LDPPermissions):
             return True
 
         return super().has_object_permission(request, view, obj)
+
+
+class CircleAccessRequestPermissions(LDPPermissions):
+    filter_backends = [CircleAccessRequestFilterBackend]
+
+    def get_object_permissions(self, request, view, obj):
+        from djangoldp_circle.models import CircleMember
+
+        perms = super().get_object_permissions(request, view, obj)
+
+        user = request.user
+        if is_authenticated_user(user):
+            # I must be an admin of the circle referenced
+            member = obj.circle.members.filter(user=user)
+            if member.exists() and member.get().is_admin:
+                perms = perms.union({'view', 'change'})
+
+        return perms
